@@ -28,11 +28,12 @@ type EcsServiceConfig struct {
 }
 
 // GetEcsServiceConfig returns config for aws_ecs_service
+// aws_ecs_service
 func GetEcsServiceConfig(c *ecs.Service) []AWSResourceConfig {
 	cf := EcsServiceConfig{
 		Config: Config{
 			Name: functions.GetVal(c.ServiceName),
-			Tags: c.Tags,
+			Tags: functions.PatchAWSTags(c.Tags),
 		},
 		IamRole: functions.GetVal(c.Role),
 	}
