@@ -29,11 +29,12 @@ type MqBrokerConfig struct {
 }
 
 // GetMqBorkerConfig returns config for aws_mq_broker
+// aws_mq_broker
 func GetMqBorkerConfig(c *amazonmq.Broker) []AWSResourceConfig {
 	cf := MqBrokerConfig{
 		Config: Config{
 			Name: c.BrokerName,
-			Tags: c.Tags,
+			Tags: functions.PatchAWSTags(c.Tags),
 		},
 		PubliclyAccessible: c.PubliclyAccessible,
 	}
